@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2020 Aurimas Cernius
+ * Copyright (C) 2011-2021 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,8 +25,6 @@
 #include <glibmm/i18n.h>
 #include <gtkmm/grid.h>
 #include <gtkmm/image.h>
-#include <gtkmm/imagemenuitem.h>
-#include <gtkmm/stock.h>
 #include <gtkmm/separator.h>
 #include <gtkmm/separatortoolitem.h>
 #include <gtkmm/separatormenuitem.h>
@@ -62,34 +60,6 @@ namespace gnote {
   }
 
 
-  NoteWindow::NonModifyingAction::NonModifyingAction()
-  {}
-
-  NoteWindow::NonModifyingAction::NonModifyingAction(const Glib::ustring & name,
-                                                     const Gtk::StockID & stock_id,
-                                                     const Glib::ustring & label,
-                                                     const Glib::ustring & tooltip)
-    : Gtk::Action(name, stock_id, label, tooltip)
-  {}
-
-  NoteWindow::NonModifyingAction::NonModifyingAction(const Glib::ustring & name,
-                                                     const Glib::ustring & icon_name,
-                                                     const Glib::ustring & label,
-                                                     const Glib::ustring & tooltip)
-    : Gtk::Action(name, icon_name, label, tooltip)
-  {}
-
-  void NoteWindow::NonModifyingAction::reference() const
-  {
-    Gtk::Action::reference();
-  }
-
-  void NoteWindow::NonModifyingAction::unreference() const
-  {
-    Gtk::Action::unreference();
-  }
-
-
 
   NoteWindow::NoteWindow(Note & note, IGnote & g)
     : m_note(note)
@@ -331,17 +301,6 @@ namespace gnote {
     return popover_widgets;
   }
 
-  std::vector<MainWindowAction::Ptr> NoteWindow::get_widget_actions()
-  {
-    std::vector<MainWindowAction::Ptr> res;
-    EmbeddableWidgetHost *h = host();
-    if(h != NULL) {
-      h->find_action("important-note");
-      h->find_action("delete-note");
-    }
-    return res;
-  }
-
     // Delete this Note.
     //
 
@@ -378,8 +337,7 @@ namespace gnote {
     Gtk::MenuItem *spacer1 = manage(new Gtk::SeparatorMenuItem());
     spacer1->show ();
 
-    Gtk::ImageMenuItem *link = manage(new Gtk::ImageMenuItem(_("_Link to New Note"), true));
-    link->set_image(*manage(new Gtk::Image (Gtk::Stock::JUMP_TO, Gtk::ICON_SIZE_MENU)));
+    auto link = manage(new Gtk::MenuItem(_("_Link to New Note"), true));
     link->set_sensitive(!m_note.get_buffer()->get_selection().empty());
     link->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::link_button_clicked));
     link->add_accelerator("activate", m_accel_group, GDK_KEY_L,
@@ -411,13 +369,13 @@ namespace gnote {
     text_button->set_image(*image);
     text_button->signal_clicked()
       .connect(sigc::mem_fun(*this, &NoteWindow::on_text_button_clicked));
-    text_button->property_margin_left() = 12;
+    text_button->property_margin_start() = 12;
     text_button->show_all();
     grid->attach(*text_button, grid_col++, 0, 1, 1);
     text_button->set_tooltip_text(_("Set properties of text"));
     m_text_menu->set_relative_to(*text_button);
 
-    grid->property_margin_left() = 12;
+    grid->property_margin_start() = 12;
     grid->show_all();
     return grid;
   }
@@ -607,12 +565,6 @@ namespace gnote {
     embeddable_toolbar()->set_sensitive(m_enabled);
     if(m_global_keys)
       m_global_keys->enabled(m_enabled);
-    for(const MainWindowAction::Ptr & action : get_widget_actions()) {
-      // A list includes empty actions to mark separators, non-modifying actions are always enabled
-      if(action && !Glib::RefPtr<NonModifyingNoteAction>::cast_dynamic(action)) {
-        action->set_enabled(enable);
-      }
-    }
   }
 
 
