@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2021 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -24,7 +24,6 @@
 #ifndef __NOTE_RECENT_CHANGES_HPP_
 #define __NOTE_RECENT_CHANGES_HPP_
 
-#include <gtkmm/alignment.h>
 #include <gtkmm/applicationwindow.h>
 #include <gtkmm/grid.h>
 #include <gtkmm/popovermenu.h>
@@ -50,6 +49,10 @@ public:
   virtual void present_search() override;
   virtual void close_window() override;
   virtual bool is_search() override;
+  virtual utils::GlobalKeybinder & keybinder() override
+    {
+      return m_keybinder;
+    }
 
   virtual void embed_widget(EmbeddableWidget &) override;
   virtual void unembed_widget(EmbeddableWidget &) override;
@@ -73,15 +76,17 @@ private:
   void on_delete_note();
   bool on_delete(GdkEventAny *);
   bool on_key_pressed(GdkEventKey *);
-  EmbeddableWidget *currently_embedded();
+  EmbeddableWidget *currently_foreground();
   void make_header_bar();
   void make_search_box();
+  void make_find_next_prev();
   bool on_entry_key_pressed(GdkEventKey *);
   void on_entry_changed();
   void on_entry_activated();
   void entry_changed_timeout();
   Glib::ustring get_search_text();
   void update_toolbar(EmbeddableWidget & widget);
+  void update_search_bar(EmbeddableWidget & widget, bool perform_search);
   void on_all_notes_button_clicked();
   void on_show_window_menu();
   void on_search_button_toggled();
@@ -89,7 +94,6 @@ private:
   void on_find_prev_button_clicked();
   Gtk::PopoverMenu *make_window_menu(Gtk::Button *button, std::vector<PopoverWidget> && items);
   void on_embedded_name_changed(const Glib::ustring & name);
-  void on_settings_changed(const Glib::ustring & key);
   bool on_notes_widget_key_press(GdkEventKey*);
   void on_close_window(const Glib::VariantBase&);
   void add_action(const MainWindowAction::Ptr & action);
@@ -99,27 +103,29 @@ private:
   NoteManagerBase    &m_note_manager;
   Preferences        &m_preferences;
   Gtk::Widget        *m_header_bar;
-  SearchNotesWidget   m_search_notes_widget;
-  Gtk::Grid           m_content_vbox;
-  Gtk::Alignment      m_search_box;
-  Gtk::Grid           m_find_next_prev_box;
+  SearchNotesWidget  *m_search_notes_widget;
+  Gtk::Grid          *m_search_box;
+  Gtk::Grid          *m_find_next_prev_box;
+  union
+  {
+    Gtk::SearchEntry *m_search_entry;
+    Glib::ustring    *m_search_text;
+  };
   Gtk::ToggleButton   m_search_button;
-  Gtk::Alignment      m_embedded_toolbar;
+  Gtk::Grid           m_embedded_toolbar;
   Gtk::Grid           m_embed_box;
   Gtk::Button        *m_all_notes_button;
   Gtk::Button        *m_new_note_button;
   Gtk::Button        *m_window_actions_button;
-  Gtk::SearchEntry    m_search_entry;
-  std::vector<EmbeddableWidget*> m_embedded_widgets;
+  EmbeddableWidget*   m_embedded_widget;
   bool                m_mapped;
   sigc::connection    m_current_embedded_name_slot;
   sigc::connection    m_signal_popover_widgets_changed_cid;
   utils::InterruptableTimeout *m_entry_changed_timeout;
   Gtk::PopoverMenu     *m_window_menu_embedded;
   Gtk::PopoverMenu     *m_window_menu_default;
+  Glib::RefPtr<Gtk::AccelGroup> m_accel_group;
   utils::GlobalKeybinder m_keybinder;
-  bool                m_open_notes_in_new_window;
-  bool                m_close_note_on_escape;
   std::map<Glib::ustring, MainWindowAction::Ptr> m_actions;
 };
 
