@@ -53,7 +53,13 @@ Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::get_note_icon(IconManager & manager
 
 
 SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
-  : m_accel_group(Gtk::AccelGroup::create())
+  : m_open_note_menu_item(nullptr)
+  , m_open_note_new_window_menu_item(nullptr)
+  , m_delete_note_menu_item(nullptr)
+  , m_delete_notebook_menu_item(nullptr)
+  , m_rename_notebook_menu_item(nullptr)
+  , m_open_note_accel(nullptr)
+  , m_open_note_new_window_accel(nullptr)
   , m_no_matches_box(NULL)
   , m_gnote(g)
   , m_manager(m)
@@ -67,7 +73,6 @@ SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
 {
   set_hexpand(true);
   set_vexpand(true);
-  make_actions();
 
   // Notebooks Pane
   Gtk::Widget *notebooksPane = Gtk::manage(make_notebooks_pane());
@@ -133,25 +138,6 @@ Glib::ustring SearchNotesWidget::get_name() const
   return selected_notebook->get_name();
 }
 
-void SearchNotesWidget::make_actions()
-{
-  m_open_note_action = Gtk::Action::create("OpenNoteAction", _("_Open"));
-  m_open_note_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note));
-
-  m_open_note_new_window_action = Gtk::Action::create("OpenNoteNewWindowAction", _("Open In New _Window"));
-  m_open_note_new_window_action->signal_activate()
-    .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note_new_window));
-
-  m_delete_note_action = Gtk::Action::create("DeleteNoteAction", _("_Delete"));
-  m_delete_note_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::delete_selected_notes));
-
-  m_delete_notebook_action = Gtk::Action::create("DeleteNotebookAction", _("_Delete"));
-  m_delete_notebook_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_delete_notebook));
-
-  m_rename_notebook_action = Gtk::Action::create("RenameNotebookAction", _("Re_name..."));
-  m_rename_notebook_action->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_rename_notebook));
-}
-
 void SearchNotesWidget::perform_search(const Glib::ustring & search_text)
 {
   restore_matches_window();
@@ -219,7 +205,6 @@ Gtk::Widget *SearchNotesWidget::make_notebooks_pane()
 
   m_notebooksTree->get_selection()->set_mode(Gtk::SELECTION_SINGLE);
   m_notebooksTree->set_headers_visible(true);
-  m_notebooksTree->set_rules_hint(false);
 
   Gtk::CellRenderer *renderer;
 
@@ -374,8 +359,12 @@ void SearchNotesWidget::on_notebook_selection_changed()
     // this handler to be called again
     m_on_notebook_selection_changed_cid.block();
     select_all_notes_notebook();
-    m_delete_notebook_action->set_sensitive(false);
-    m_rename_notebook_action->set_sensitive(false);
+    if(m_delete_notebook_menu_item) {
+      m_delete_notebook_menu_item->set_sensitive(false);
+    }
+    if(m_rename_notebook_menu_item) {
+      m_rename_notebook_menu_item->set_sensitive(false);
+    }
     m_on_notebook_selection_changed_cid.unblock();
   }
   else {
@@ -385,12 +374,20 @@ void SearchNotesWidget::on_notebook_selection_changed()
     }
     bool allow_edit = false;
     if(std::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
-      m_delete_notebook_action->set_sensitive(false);
-      m_rename_notebook_action->set_sensitive(false);
+      if(m_delete_notebook_menu_item) {
+        m_delete_notebook_menu_item->set_sensitive(false);
+      }
+      if(m_rename_notebook_menu_item) {
+        m_rename_notebook_menu_item->set_sensitive(false);
+      }
     }
     else {
-      m_delete_notebook_action->set_sensitive(true);
-      m_rename_notebook_action->set_sensitive(true);
+      if(m_delete_notebook_menu_item) {
+        m_delete_notebook_menu_item->set_sensitive(true);
+      }
+      if(m_rename_notebook_menu_item) {
+        m_rename_notebook_menu_item->set_sensitive(true);
+      }
       allow_edit = true;
     }
 
@@ -663,7 +660,6 @@ void SearchNotesWidget::make_recent_tree()
 
   m_tree = manage(new RecentTreeView());
   m_tree->set_headers_visible(true);
-  m_tree->set_rules_hint(true);
   m_tree->signal_row_activated().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_row_activated));
   m_tree->get_selection()->set_mode(Gtk::SELECTION_MULTIPLE);
   m_tree->get_selection()->signal_changed().connect(
@@ -795,14 +791,26 @@ void SearchNotesWidget::on_selection_changed()
   Note::List selected_notes = get_selected_notes();
 
   if(selected_notes.empty()) {
-    m_open_note_action->property_sensitive() = false;
-    m_open_note_new_window_action->property_sensitive() = false;
-    m_delete_note_action->property_sensitive() = false;
+    if(m_open_note_menu_item) {
+      m_open_note_menu_item->property_sensitive() = false;
+    }
+    if(m_open_note_new_window_menu_item) {
+      m_open_note_new_window_menu_item->property_sensitive() = false;
+    }
+    if(m_delete_note_menu_item) {
+      m_delete_note_menu_item->property_sensitive() = false;
+    }
   }
   else {
-    m_open_note_action->property_sensitive() = true;
-    m_open_note_new_window_action->property_sensitive() = true;
-    m_delete_note_action->property_sensitive() = true;
+    if(m_open_note_menu_item) {
+      m_open_note_menu_item->property_sensitive() = true;
+    }
+    if(m_open_note_new_window_menu_item) {
+      m_open_note_new_window_menu_item->property_sensitive() = true;
+    }
+    if(m_delete_note_menu_item) {
+      m_delete_note_menu_item->property_sensitive() = true;
+    }
   }
 }
 
@@ -928,7 +936,7 @@ bool SearchNotesWidget::on_treeview_motion_notify(GdkEventMotion *ev)
     return retval;
   }
 
-  m_tree->drag_begin(Gtk::TargetList::create (m_targets), Gdk::ACTION_MOVE, 1, event);
+  m_tree->drag_begin(Gtk::TargetList::create (m_targets), Gdk::ACTION_MOVE, 1, event, 0, 0);
   return retval;
 }
 
@@ -1030,15 +1038,12 @@ void SearchNotesWidget::no_matches_found_action()
     link_button->signal_activate_link()
       .connect(sigc::mem_fun(*this, &SearchNotesWidget::show_all_search_results), false);
     link_button->set_tooltip_text(_("Click here to search across all notebooks"));
+    link_button->set_halign(Gtk::ALIGN_CENTER);
+    link_button->set_valign(Gtk::ALIGN_CENTER);
     link_button->show();
-    Gtk::Alignment *no_matches_found = manage(new Gtk::Alignment(Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER, 0.0, 0.0));
-    no_matches_found->add(*link_button);
 
-    no_matches_found->set_hexpand(true);
-    no_matches_found->set_vexpand(true);
-    no_matches_found->show_all();
     m_no_matches_box = new Gtk::Grid;
-    m_no_matches_box->attach(*no_matches_found, 0, 0, 1, 1);
+    m_no_matches_box->attach(*link_button, 0, 0, 1, 1);
     m_no_matches_box->show();
   }
   add2(*m_no_matches_box);
@@ -1297,28 +1302,27 @@ Gtk::Menu *SearchNotesWidget::get_note_list_context_menu()
 
     Gtk::MenuItem *item;
     if(!m_gnote.preferences().open_notes_in_new_window()) {
-      item = manage(new Gtk::MenuItem);
-      item->set_related_action(m_open_note_action);
-      item->add_accelerator("activate", m_accel_group, GDK_KEY_O, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
-      m_note_list_context_menu->add(*item);
+      m_open_note_menu_item = manage(new Gtk::MenuItem(_("_Open"), true));
+      m_open_note_menu_item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note));
+      m_note_list_context_menu->add(*m_open_note_menu_item);
     }
 
-    item = manage(new Gtk::MenuItem);
-    item->set_related_action(m_open_note_new_window_action);
-    item->add_accelerator("activate", m_accel_group, GDK_KEY_W, Gdk::MOD1_MASK, Gtk::ACCEL_VISIBLE);
-    m_note_list_context_menu->add(*item);
+    m_open_note_new_window_menu_item = manage(new Gtk::MenuItem(_("Open In New _Window"), true));
+    m_open_note_new_window_menu_item->signal_activate()
+      .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note_new_window));
+    m_note_list_context_menu->add(*m_open_note_new_window_menu_item);
 
-    item = manage(new Gtk::MenuItem);
-    item->set_related_action(m_delete_note_action);
-    m_note_list_context_menu->add(*item);
+    m_delete_note_menu_item = manage(new Gtk::MenuItem(_("_Delete"), true));
+    m_delete_note_menu_item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::delete_selected_notes));
+    m_note_list_context_menu->add(*m_delete_note_menu_item);
 
     m_note_list_context_menu->add(*manage(new Gtk::SeparatorMenuItem));
     item = manage(new Gtk::MenuItem(_("_New"), true));
-    item->add_accelerator("activate", m_accel_group, GDK_KEY_N, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::new_note));
     m_note_list_context_menu->add(*item);
   }
 
+  on_selection_changed();
   return m_note_list_context_menu;
 }
 
@@ -1346,12 +1350,12 @@ Gtk::Menu *SearchNotesWidget::get_notebook_list_context_menu()
     item->signal_activate()
       .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_notebook_template_note));
     m_notebook_list_context_menu->add(*item);
-    item = manage(new Gtk::MenuItem);
-    item->set_related_action(m_rename_notebook_action);
-    m_notebook_list_context_menu->add(*item);
-    item = manage(new Gtk::MenuItem);
-    item->set_related_action(m_delete_notebook_action);
-    m_notebook_list_context_menu->add(*item);
+    m_rename_notebook_menu_item = manage(new Gtk::MenuItem(_("Re_name..."), true));
+    m_rename_notebook_menu_item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_rename_notebook));
+    m_notebook_list_context_menu->add(*m_rename_notebook_menu_item);
+    m_delete_notebook_menu_item = manage(new Gtk::MenuItem(_("_Delete"), true));
+    m_delete_notebook_menu_item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_delete_notebook));
+    m_notebook_list_context_menu->add(*m_delete_notebook_menu_item);
     m_notebook_list_context_menu->add(*manage(new Gtk::SeparatorMenuItem));
     item = manage(new Gtk::MenuItem(_("_New..."), true));
     item->signal_activate()
@@ -1359,6 +1363,7 @@ Gtk::Menu *SearchNotesWidget::get_notebook_list_context_menu()
     m_notebook_list_context_menu->add(*item);
   }
 
+  on_notebook_selection_changed();
   return m_notebook_list_context_menu;
 }
 
@@ -1400,7 +1405,8 @@ void SearchNotesWidget::foreground()
     return;
   }
 
-  win->add_accel_group(m_accel_group);
+  m_open_note_accel = win->keybinder().add_accelerator(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note), GDK_KEY_O, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+  m_open_note_new_window_accel = win->keybinder().add_accelerator(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note_new_window), GDK_KEY_W, Gdk::MOD1_MASK, Gtk::ACCEL_VISIBLE);
   auto & manager(m_gnote.action_manager());
   register_callbacks();
   m_callback_changed_cid = manager.signal_main_window_search_actions_changed
@@ -1413,10 +1419,14 @@ void SearchNotesWidget::background()
   save_position();
   unregister_callbacks();
   m_callback_changed_cid.disconnect();
-  Gtk::Window *win = dynamic_cast<Gtk::Window*>(host());
-  if(win) {
-    win->remove_accel_group(m_accel_group);
+  MainWindow *win = dynamic_cast<MainWindow*>(host());
+  if(!win) {
+    return;
   }
+  win->keybinder().remove_accelerator(m_open_note_accel);
+  win->keybinder().remove_accelerator(m_open_note_new_window_accel);
+  m_open_note_accel = nullptr;
+  m_open_note_new_window_accel = nullptr;
 }
 
 void SearchNotesWidget::hint_size(int & width, int & height)
@@ -1452,17 +1462,14 @@ std::vector<PopoverWidget> SearchNotesWidget::get_popover_widgets()
   return popover_widgets;
 }
 
-std::vector<MainWindowAction::Ptr> SearchNotesWidget::get_widget_actions()
-{
-  std::vector<MainWindowAction::Ptr> actions;
-  return actions;
-}
-
 void SearchNotesWidget::on_settings_changed()
 {
   if(m_note_list_context_menu) {
     delete m_note_list_context_menu;
     m_note_list_context_menu = NULL;
+    m_open_note_menu_item = nullptr;
+    m_open_note_new_window_menu_item = nullptr;
+    m_delete_note_menu_item = nullptr;
   }
 }
 
